@@ -7,7 +7,7 @@ use Lexical::SealRequireHints 0.006;
 use Importer 0.013;
 use parent 'Importer';
 
-our $VERSION = "0.000004";
+our $VERSION = "0.000005";
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -72,7 +72,7 @@ Say you have a module, C<Foo.pm>:
     use base 'Exporter';
     our @EXPORT = qw/foo/;
 
-    sub foo { 'not lexical' }
+    sub foo { 'foo' }
 
 You want to import C<foo()> to use, but you also have your own C<foo()> method
 you do not want to squash in C<Your::Module.pm>
@@ -138,7 +138,7 @@ under the same terms as Perl itself.
 =head1 SOURCE
 
 The source code repository for Lexical-Importer can be found at
-F<http://github.com/FIXME/>.
+F<https://github.com/exodist/Lexical-Importer>.
 
 =head1 MAINTAINERS
 
